'use client';

import { ReactNode } from 'react';
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from '@/components/ui/table';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';

interface Column {
  key: string;
  header: string;
  render?: (value: unknown, row: Record<string, unknown>) => ReactNode;
  mobilePriority?: boolean; // Whether to show this column on mobile
}

interface ResponsiveTableProps {
  columns: Column[];
  data: Record<string, unknown>[];
  className?: string;
}

export function ResponsiveTable({ columns, data, className }: ResponsiveTableProps) {
  const mobileColumns = columns.filter(col => col.mobilePriority !== false);
  
  return (
    <div className={className}>
      {/* Desktop Table */}
      <div className="hidden md:block">
        <Table>
          <TableHeader>
            <TableRow>
              {columns.map((column) => (
                <TableHead key={column.key}>{column.header}</TableHead>
              ))}
            </TableRow>
          </TableHeader>
          <TableBody>
            {data.map((row, index) => (
              <TableRow key={(row.id as string) || index}>
                {columns.map((column) => (
                  <TableCell key={column.key}>
                    {column.render 
                      ? column.render(row[column.key], row)
                      : String(row[column.key] || '')
                    }
                  </TableCell>
                ))}
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </div>

      {/* Mobile Cards */}
      <div className="md:hidden space-y-4">
        {data.map((row, index) => (
          <Card key={(row.id as string) || index} className="overflow-hidden">
            <CardHeader className="pb-3">
              <CardTitle className="text-lg">
                {mobileColumns[0]?.render 
                  ? mobileColumns[0].render(row[mobileColumns[0]?.key || ''], row)
                  : String(row[mobileColumns[0]?.key || ''] || '')
                }
              </CardTitle>
            </CardHeader>
            <CardContent className="space-y-2">
              {mobileColumns.slice(1).map((column) => (
                <div key={column.key} className="flex justify-between items-start">
                  <span className="font-medium text-sm text-gray-600 min-w-0 flex-1">
                    {column.header}:
                  </span>
                  <span className="text-sm text-gray-900 text-right ml-2 min-w-0 flex-1">
                    {column.render 
                      ? column.render(row[column.key], row)
                      : String(row[column.key] || '')
                    }
                  </span>
                </div>
              ))}
            </CardContent>
          </Card>
        ))}
      </div>
    </div>
  );
} 